@@ -19,39 +19,39 @@
 #include "out123_int.h"
 #include "compat.h"
 
-int  buffer_init(out123_handle *ao, size_t bytes);
-void buffer_exit(out123_handle *ao);
+int  INT123_buffer_init(out123_handle *ao, size_t bytes);
+void INT123_buffer_exit(out123_handle *ao);
 
 /* Messages with payload. */
 
-int buffer_sync_param(out123_handle *ao);
-int buffer_open(out123_handle *ao, const char* driver, const char* device);
-int buffer_encodings(out123_handle *ao);
-int buffer_formats( out123_handle *ao, const long *rates, int ratecount
+int INT123_buffer_sync_param(out123_handle *ao);
+int INT123_buffer_open(out123_handle *ao, const char* driver, const char* device);
+int INT123_buffer_encodings(out123_handle *ao);
+int INT123_buffer_formats( out123_handle *ao, const long *rates, int ratecount
                   , int minchannels, int maxchannels
                   , struct mpg123_fmt **fmtlist );
-int buffer_start(out123_handle *ao);
-void buffer_ndrain(out123_handle *ao, size_t bytes);
+int INT123_buffer_start(out123_handle *ao);
+void INT123_buffer_ndrain(out123_handle *ao, size_t bytes);
 
 /* Simple messages to be deal with after playback. */
 
-void buffer_stop(out123_handle *ao);
-void buffer_close(out123_handle *ao);
-void buffer_continue(out123_handle *ao);
+void INT123_buffer_stop(out123_handle *ao);
+void INT123_buffer_close(out123_handle *ao);
+void INT123_buffer_continue(out123_handle *ao);
 /* Still undecided if that one is to be used anywhere. */
-void buffer_ignore_lowmem(out123_handle *ao);
-void buffer_drain(out123_handle *ao);
-void buffer_end(out123_handle *ao);
+void INT123_buffer_ignore_lowmem(out123_handle *ao);
+void INT123_buffer_drain(out123_handle *ao);
+void INT123_buffer_end(out123_handle *ao);
 
 /* Simple messages with interruption of playback. */
 
-void buffer_pause(out123_handle *ao);
-void buffer_drop(out123_handle *ao);
+void INT123_buffer_pause(out123_handle *ao);
+void INT123_buffer_drop(out123_handle *ao);
 
 /* The actual work: Hand over audio data. */
-size_t buffer_write(out123_handle *ao, void *buffer, size_t bytes);
+size_t INT123_buffer_write(out123_handle *ao, void *buffer, size_t bytes);
 
 /* Thin wrapper over xfermem giving the current buffer fill. */
-size_t buffer_fill(out123_handle *ao);
+size_t INT123_buffer_fill(out123_handle *ao);
 
 #endif
